==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/core/com/db4o/foundation/network/YapServerSocket.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.foundation.network
{
	public class YapServerSocket
	{
		private j4o.net.ServerSocket _serverSocket;

		public YapServerSocket(int port)
		{
			_serverSocket = new j4o.net.ServerSocket(port);
		}

		public virtual void setSoTimeout(int timeout)
		{
			try
			{
				_serverSocket.setSoTimeout(timeout);
			}
			catch (System.Net.Sockets.SocketException e)
			{
				j4o.lang.JavaSystem.printStackTrace(e);
			}
		}

		public virtual int getLocalPort()
		{
			return _serverSocket.getLocalPort();
		}

		public virtual com.db4o.foundation.network.YapSocket accept()
		{
			j4o.net.Socket sock = _serverSocket.accept();
			return new com.db4o.foundation.network.YapSocketReal(sock);
		}

		public virtual void close()
		{
			_serverSocket.close();
		}
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/core/com/db4o/foundation/network/YapServerSocket.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.foundation.network
{
	public class YapServerSocket
	{
		private j4o.net.ServerSocket _serverSocket;

		public YapServerSocket(int port)
		{
			_serverSocket = new j4o.net.ServerSocket(port);
		}

		public virtual void SetSoTimeout(int timeout)
		{
			try
			{
				_serverSocket.SetSoTimeout(timeout);
			}
			catch (System.Net.Sockets.SocketException e)
			{
				j4o.lang.JavaSystem.PrintStackTrace(e);
			}
		}

		public virtual int GetLocalPort()
		{
			return _serverSocket.GetLocalPort();
		}

		public virtual com.db4o.foundation.network.YapSocket Accept()
		{
			j4o.net.Socket sock = _serverSocket.Accept();
			return new com.db4o.foundation.network.YapSocketReal(sock);
		}

		public virtual void Close()
		{
			_serverSocket.Close();
		}
	}
}
